# Component: {{ target_component_name }}
# Efficient Cause: {{ target_component_name }} is required in this pipeline since the dataset has {{ relevant_meta_feature_list }}. The relevant features are: {{ relevant_column_list }}.
# Purpose: {{ api_description }}
# Form:
#   Input: {{ data_shape }}
#   Key hyperparameters used: {{ hyperparameters_description }}
# Alternatives: Although {{ alternative_component_list }} can also be used for this dataset, {{ target_component_name }} is used because it has more {{ relevant_meta_feature_1 }} than {{ relevant_meta_feature_2 }}.
# Order: {{ target_component_name }} should be applied {{ before_or_after }} {{ dependent_component_list }}